summaryrefslogtreecommitdiffstats
path: root/views/views_delegate.h
diff options
context:
space:
mode:
authordhollowa@chromium.org <dhollowa@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-08-31 23:27:33 +0000
committerdhollowa@chromium.org <dhollowa@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-08-31 23:27:33 +0000
commit0fbe67bd15d7e81751ac0532a388315a714ccb6c (patch)
treeb638b9f2c220e2dd2057fd7b1d764b4f7ba6a7d8 /views/views_delegate.h
parentbba630ced52644aaeab2a3e3d5c8348acdcca543 (diff)
downloadchromium_src-0fbe67bd15d7e81751ac0532a388315a714ccb6c.zip
chromium_src-0fbe67bd15d7e81751ac0532a388315a714ccb6c.tar.gz
chromium_src-0fbe67bd15d7e81751ac0532a388315a714ccb6c.tar.bz2
Restoring a session should restore window minimization state on Windows
These changes enable save and restore of minimized window state on Windows. (Mac and Linux came prior). The window state is now saved whenever size-changed notifications fire (in addition to the original activation and close cases). BUG=43274 TEST=Manual. Launch Chrome on Windows, create two browser windows, minimize "a" window, quit. Relaunch, expect "a" to be minimized. Committed: http://src.chromium.org/viewvc/chrome?view=rev&revision=98679 Review URL: http://codereview.chromium.org/7748036 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@99077 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'views/views_delegate.h')
-rw-r--r--views/views_delegate.h22
1 files changed, 10 insertions, 12 deletions
diff --git a/views/views_delegate.h b/views/views_delegate.h
index 13baff0..4b032c3 100644
--- a/views/views_delegate.h
+++ b/views/views_delegate.h
@@ -12,6 +12,7 @@
#endif
#include "ui/base/accessibility/accessibility_types.h"
+#include "ui/base/ui_base_types.h"
#include "views/views_export.h"
namespace gfx {
@@ -46,22 +47,19 @@ class VIEWS_EXPORT ViewsDelegate {
// TODO(beng): perhaps this should be a Widget.
virtual View* GetDefaultParentView() = 0;
// Saves the position, size and maximized state for the window with the
// specified name.
virtual void SaveWindowPlacement(const Widget* widget,
const std::wstring& window_name,
const gfx::Rect& bounds,
- bool maximized) = 0;
-
- // Retrieves the saved position and size for the window with the specified
- // name.
- virtual bool GetSavedWindowBounds(const std::wstring& window_name,
- gfx::Rect* bounds) const = 0;
-
- // Retrieves the saved maximized state for the window with the specified
- // name.
- virtual bool GetSavedMaximizedState(const std::wstring& window_name,
- bool* maximized) const = 0;
+ ui::WindowShowState show_state) = 0;
+
+ // Retrieves the saved position and size and "show" state for the window with
+ // the specified name.
+ virtual bool GetSavedWindowPlacement(
+ const std::wstring& window_name,
+ gfx::Rect* bounds,
+ ui::WindowShowState* show_state) const = 0;
virtual void NotifyAccessibilityEvent(
views::View* view, ui::AccessibilityTypes::Event event_type) = 0;
@@ -46,22 +47,19 @@ class VIEWS_EXPORT ViewsDelegate {
// TODO(beng): perhaps this should be a Widget.
virtual View* GetDefaultParentView() = 0;
- // Saves the position, size and maximized state for the window with the
+ // Saves the position, size and "show" state for the window with the
// specified name.
virtual void SaveWindowPlacement(const Widget* widget,